@@ -5,6 +5,28 @@
 #include "narray.h"
 #include "mpi.h"
 
+#if SIZEOF_SHORT == 2
+# define NA_MPI_SINT MPI_SHORT
+#else
+---->> Please define NA_MPI_SINT manually because sizeof(short) != 2. <<----
+#endif
+
+#if SIZEOF_LONG == 4
+# define NA_MPI_LINT MPI_LONG
+#else
+# if SIZEOF_INT == 4
+#  define NA_MPI_LINT MPI_INT
+# else
+---->> Please define NA_MPI_LINT manually because sizeof(long) != 4. <<----
+# endif
+#endif
+
+#if SIZEOF_LONG_LONG == 8
+# define NA_MPI_LLINT MPI_LONG_LONG
+#else
+---->> Please define NA_MPI_LLINT manually because sizeof(long long) != 8. <<----
+#endif
+
 
 #define OBJ2C(rb_obj, len, buffer, typ, off) \
 {\
@@ -23,11 +45,15 @@
       buffer = (void*)((char*)buffer + off);\
       break;\
     case NA_SINT:\
-      typ = MPI_SHORT;\
-      buffer = (void*)((char*)buffer + off*4);\
+      typ = NA_MPI_SINT;\
+      buffer = (void*)((char*)buffer + off*2);\
       break;\
     case NA_LINT:\
-      typ = MPI_LONG;\
+      typ = NA_MPI_LINT;\
+      buffer = (void*)((char*)buffer + off*4);\
+      break;\
+    case NA_LLINT:\
+      typ = NA_MPI_LLINT;\
       buffer = (void*)((char*)buffer + off*8);\
       break;\
     case NA_SFLOAT:\
@@ -171,9 +197,9 @@ name ## _free2(void *ptr)\
   obj = (struct _ ## name*) ptr;\
   free(obj);\
 }
-DEF_FREE(Comm, COMM)
+//DEF_FREE(Comm, COMM)
 DEF_FREE(Request, REQUEST)
-DEF_FREE(Op, OP)
+//DEF_FREE(Op, OP)
 DEF_FREE(Errhandler, ERRHANDLER)
 DEF_FREE2(Comm, COMM)
 DEF_FREE2(Op, OP)
@@ -244,7 +270,7 @@ rb_m_init(int argc, VALUE *argv, VALUE self)
   // define MPI::Comm::WORLD
   struct _Comm *Comm;
   DEF_CONST(Comm, MPI_COMM_WORLD, WORLD);
-  check_error(MPI_Errhandler_set(MPI_COMM_WORLD, MPI_ERRORS_RETURN));
+  check_error(MPI_Comm_set_errhandler(MPI_COMM_WORLD, MPI_ERRORS_RETURN));
 
   // define MPI::Op::???
   struct _Op *Op;
@@ -289,18 +315,21 @@ rb_m_abort(VALUE self, VALUE rcomm, VALUE rerror)
 
 
 // MPI::Comm
+/*
 static VALUE
 rb_comm_alloc(VALUE klass)
 {
   struct _Comm *ptr = ALLOC(struct _Comm);
   return Data_Wrap_Struct(klass, NULL, Comm_free, ptr);
 }
+*/
 static VALUE
 rb_comm_initialize(VALUE self)
 {
   rb_raise(rb_eRuntimeError, "not developed yet");
   // MPI_Comm_create()
   // comm->free = true;
+  return Qnil;
 }
 static VALUE
 rb_comm_size(VALUE self)
@@ -666,8 +695,6 @@ rb_status_error(VALUE self)
 void Init_mpi()
 {
 
-  rb_require("narray");
-
   // MPI
   mMPI = rb_define_module("MPI");
   rb_define_module_function(mMPI, "Init", rb_m_init, -1);
