@@ -1,5 +1,9 @@
 require File.expand_path(File.dirname(__FILE__) + '/spec_helper')
 
+if defined?(NumRu::NArray)
+  include NumRu
+end
+
 describe "MPI" do
   before(:all) do
     MPI.Init()
@@ -13,14 +17,14 @@ describe "MPI" do
   end
 
   it "should give version" do
-    MPI::VERSION.class.should eql(Fixnum)
-    MPI::SUBVERSION.class.should eql(Fixnum)
+    expect(MPI::VERSION.class).to eq(Fixnum)
+    expect(MPI::SUBVERSION.class).to eq(Fixnum)
   end
 
   it "should give rank and size" do
-    @world.rank.class.should eql(Fixnum)
-    @world.size.class.should eql(Fixnum)
-    @world.size.should > 0
+    expect(@world.rank.class).to eql(Fixnum)
+    expect(@world.size.class).to eql(Fixnum)
+    expect(@world.size).to be > 0
   end
 
   it "should send and receive String" do
@@ -32,33 +36,32 @@ describe "MPI" do
       (@world.size-1).times do |i|
         str = " "*"Hello from #{i+1}".length
         status = @world.Recv(str, i+1, tag)
-        status.source.should eql(i+1)
-        status.tag.should eql(tag)
-        str.should match(/\AHello from #{i+1}/)
+        expect(status.source).to eql(i+1)
+        expect(status.tag).to eql(tag)
+        expect(str).to match /\AHello from #{i+1}/
       end
     end
   end
 
   it "should send and receive NArray" do
-    tag = 1
+    tag = 10
     rank = @world.rank
-    [NArray[1,2,3], NArray[3.0,2.0,1.0]].each do |ary0|
-      ary0 = NArray[1,2,3]
-      @world.Send(ary0, 0, tag) if rank != 0
+    [NArray[1,2,3], NArray[3.0,2.0,1.0]].each_with_index do |ary0,j|
+      @world.Send(ary0, 0, tag+j) if rank != 0
       if rank == 0
         (@world.size-1).times do |i|
           ary1 = NArray.new(ary0.typecode, ary0.total)
-          status = @world.Recv(ary1, i+1, tag)
-          status.source.should eql(i+1)
-          status.tag.should eql(tag)
-          ary1.should == ary0
+          status = @world.Recv(ary1, i+1, tag+j)
+          expect(status.source).to eql(i+1)
+          expect(status.tag).to eql(tag+j)
+          expect(ary1).to be == ary0
         end
       end
     end
   end
 
   it "should send and receive without blocking" do
-    tag = 2
+    tag = 20
     rank = @world.rank
     message = "Hello from #{rank}"
     if rank != 0
@@ -70,9 +73,9 @@ describe "MPI" do
         str = " "*"Hello from #{i+1}".length
         request_recv = @world.Irecv(str, i+1, tag)
         status = request_recv.Wait
-        status.source.should eql(i+1)
-        status.tag.should eql(tag)
-        str.should match(/\AHello from #{i+1}/)
+        expect(status.source).to eql(i+1)
+        expect(status.tag).to eql(tag)
+        expect(str).to match(/\AHello from #{i+1}/)
       end
     end
   end
@@ -88,7 +91,7 @@ describe "MPI" do
     if rank == root
       str = ""
       size.times{|i| str << i.to_s*bufsize}
-      recvbuf.should eql(str)
+      expect(recvbuf).to eql(str)
     end
   end
 
@@ -101,7 +104,7 @@ describe "MPI" do
     @world.Allgather(sendbuf, recvbuf)
     str = ""
     size.times{|i| str << i.to_s*bufsize}
-    recvbuf.should eql(str)
+    expect(recvbuf).to eql(str)
   end
 
   it "should broad cast data (bcast)" do
@@ -114,7 +117,7 @@ describe "MPI" do
       buffer = " "*bufsize
     end
     @world.Bcast(buffer, root)
-    buffer.should eql(root.to_s*bufsize)
+    expect(buffer).to eql(root.to_s*bufsize)
   end
 
   it "should scatter data" do
@@ -130,7 +133,7 @@ describe "MPI" do
     end
     recvbuf = " "*bufsize
     @world.Scatter(sendbuf, recvbuf, root)
-    recvbuf.should eql(rank.to_s*bufsize)
+    expect(recvbuf).to eql(rank.to_s*bufsize)
   end
 
   it "should send and recv data (sendrecv)" do
@@ -142,14 +145,14 @@ describe "MPI" do
     source = rank+1
     source = 0 if source > size-1
     #source = MPI::PROC_NULL if source > size-1
-    sendtag = rank
-    recvtag = source
+    sendtag = 30 + rank
+    recvtag = 30 + source
     bufsize = 2
     sendbuf = rank.to_s*bufsize
     recvbuf = " "*bufsize
     @world.Sendrecv(sendbuf, dest, sendtag, recvbuf, source, recvtag);
     if source != MPI::PROC_NULL
-      recvbuf.should  eql(source.to_s*bufsize)
+      expect(recvbuf).to  eql(source.to_s*bufsize)
     end
   end
 
@@ -162,7 +165,7 @@ describe "MPI" do
     @world.Alltoall(sendbuf, recvbuf)
     str = ""
     size.times{|i| str << i.to_s*bufsize}
-    recvbuf.should eql(str)
+    expect(recvbuf).to eql(str)
   end
 
   it "should reduce data" do
@@ -175,7 +178,7 @@ describe "MPI" do
     @world.Reduce(sendbuf, recvbuf, MPI::Op::SUM, root)
     if rank == root
       ary = NArray.new(sendbuf.typecode,bufsize).fill(size*(size-1)/2.0)
-      recvbuf.should == ary
+      expect(recvbuf).to be == ary
     end
   end
 
@@ -187,7 +190,7 @@ describe "MPI" do
     recvbuf = NArray.new(sendbuf.typecode,bufsize)
     @world.Allreduce(sendbuf, recvbuf, MPI::Op::SUM)
     ary = NArray.new(sendbuf.typecode,bufsize).fill(size*(size-1)/2.0)
-    recvbuf.should == ary
+    expect(recvbuf).to be == ary
   end
 
   it "should not raise exception in calling barrier" do
@@ -196,8 +199,8 @@ describe "MPI" do
 
 
   it "shoud raise exeption" do
-    lambda{ @world.Send("", @world.size+1, 0) }.should raise_error(MPI::ERR::RANK)
-    @world.Errhandler.should eql(MPI::Errhandler::ERRORS_RETURN)
+    expect { @world.Send("", @world.size+1, 0) }.to raise_error(MPI::ERR::RANK)
+    expect(@world.Errhandler).to eql(MPI::Errhandler::ERRORS_RETURN)
   end
 
 end
